#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-JUulTfZKBZC2vlkmUFi6Ft
key:                  warp-3.4.0-JUulTfZKBZC2vlkmUFi6Ft
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  91835c3ce27a5d5af6083bba9aa6d639
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-JUulTfZKBZC2vlkmUFi6Ft
depends:
    array-0.5.6.0 auto-update-0.1.6-DMlu9LigmlmKEpjKplWxWa
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-4vWDGm1cuI37jdEja1iZG8
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Jy8OxWsCrDaBhFbgZ9qrNJ
    containers-0.6.7 crypton-x509-1.7.7-BK88pXiLGw7Fc3xrqCNvdh
    ghc-prim-0.10.0 hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p
    http-date-0.0.11-DIXrushX9L96bbvl3LyVVs
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    http2-5.1.1-5dhGyKulB8XDLly66Ad3Sf
    iproute-1.7.15-KClaObLBzzKHiOMGhrDuI1
    network-3.1.4.0-5QGUGxzwH322yW8TioI43L
    recv-0.1.1-5GPqQaWUVckBcL34j5q3Cq
    simple-sendfile-0.2.32-JBdWBtZ9v71JGq9zVR0qo2 stm-2.5.1.0
    streaming-commons-0.2.3.1-17zpNWcota6C45Ep9hbeLA text-2.0.2
    time-manager-0.0.1-GKlgqMyCon27wJua2LjCeh unix-2.8.4.0
    unliftio-0.2.25.1-406ICvddDrs4REwMxxdvSj
    vault-0.3.1.6-A5QxZPtM2gzJvo6AYwAPI7
    wai-3.2.4-IVqPMwlk2Y5DK0IkF0sPx word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

